"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getCacheIdentifier_1 = __importDefault(require("react-dev-utils/getCacheIdentifier"));
const environment_1 = require("../environment");
function createConfigForReact(options) {
    const production = environment_1.isProduction(options.env);
    return {
        babelrc: false,
        cacheCompression: production,
        cacheDirectory: true,
        cacheIdentifier: getCacheIdentifier_1.default(options.env, [
            'babel-plugin-named-asset-import',
            'babel-preset-react-app',
            'react-dev-utils',
        ]),
        compact: production,
        configFile: false,
        customize: require.resolve('babel-preset-react-app/webpack-overrides'),
        plugins: [
            [
                require.resolve('babel-plugin-named-asset-import'),
                {
                    loaderMap: {
                        svg: {
                            ReactComponent: '@svgr/webpack?-prettier,-svgo![path]',
                        },
                    },
                },
            ],
        ],
        presets: [
            [
                require.resolve('babel-preset-react-app'),
                {
                    flow: false,
                    typescript: true,
                },
            ],
        ],
    };
}
exports.createConfigForReact = createConfigForReact;
function createConfigForDependencies(options) {
    return {
        babelrc: false,
        cacheCompression: environment_1.isProduction(options.env),
        cacheDirectory: true,
        cacheIdentifier: getCacheIdentifier_1.default(options.env, [
            'babel-preset-react-app',
            'react-dev-utils',
        ]),
        compact: false,
        configFile: false,
        presets: [
            [
                require.resolve('babel-preset-react-app/dependencies'),
                { helpers: true },
            ],
        ],
        // If an error happens in a package, it's possible to be
        // because it was compiled. Thus, we don't want the browser
        // debugger to show the original code. Instead, the code
        // being evaluated would be much more helpful.
        sourceMaps: false,
    };
}
exports.createConfigForDependencies = createConfigForDependencies;
//# sourceMappingURL=config.js.map