"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typedoc_1 = require("typedoc");
const environment_1 = require("../../environment");
const packager_1 = require("../../packager");
const paths_1 = require("../../paths");
const command_1 = require("../command");
var ExitCode;
(function (ExitCode) {
    ExitCode[ExitCode["CompileError"] = 4] = "CompileError";
})(ExitCode = exports.ExitCode || (exports.ExitCode = {}));
const docsCommand = command_1.createCommand({
    dashed: false,
    description: 'Generates documentation using TypeDoc',
    env: environment_1.Environments.development,
    async run(toolbox) {
        const options = toolbox.parameters.options || {};
        const pkg = packager_1.readPackage(paths_1.CWD);
        const config = {
            exclude: [
                'node_modules',
                '**/__tests__/**',
                '**/__mocks__/**',
                '**/*.test.ts?x',
                '**/*.spec.ts?x',
            ],
            excludeExternals: true,
            ignoreCompilerErrors: true,
            includeDeclarations: true,
            jsx: true,
            module: 'esnext',
            name: `${pkg.name} (${pkg.version})`,
            readme: paths_1.README_PATH,
            target: 'esnext',
            ...options,
        };
        const app = new typedoc_1.Application(config);
        const src = app.expandInputFiles([paths_1.SRC_PATH]);
        const project = app.convert(src);
        if (!project) {
            process.exit(ExitCode.CompileError);
            return;
        }
        app.generateDocs(project, paths_1.DOCS_PATH);
        app.generateJson(project, paths_1.JSON_DOCS_PATH);
    },
});
exports.default = docsCommand;
//# sourceMappingURL=docs.js.map