"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gluegun_1 = require("gluegun");
const environment_1 = require("../../environment");
const packager_1 = require("../../packager");
const paths_1 = require("../../paths");
const command_1 = require("../command");
function printOutput(params) {
    const fileName = packager_1.getTarballFileName(params.packageManager, params.pkg);
    if (params.output.includes('success Wrote tarball to') ||
        params.output.includes(fileName)) {
        const filePath = paths_1.resolve(fileName)(params.appPath);
        gluegun_1.print.success(`Tarball Created: ${filePath}`);
        return;
    }
    gluegun_1.print.info(params.output);
}
const packCommand = command_1.createCommand({
    dashed: false,
    description: 'Enhance pack command',
    env: environment_1.Environments.production,
    async run() {
        const { pkg, distDir } = await packager_1.preparePackage(paths_1.CWD);
        const packageManager = environment_1.getPackageManager();
        const cmdArgs = [packageManager, 'pack', distDir];
        const command = cmdArgs.join(' ');
        gluegun_1.print.info(`Running: ${command}`);
        const output = await gluegun_1.system.run(command);
        printOutput({
            appPath: paths_1.CWD,
            output,
            packageManager,
            pkg,
        });
    },
});
exports.default = packCommand;
//# sourceMappingURL=pack.js.map