"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gluegun_1 = require("gluegun");
const environment_1 = require("../../environment");
const packager_1 = require("../../packager");
const paths_1 = require("../../paths");
const command_1 = require("../command");
const publishCommand = command_1.createCommand({
    dashed: false,
    description: 'Enhance publish command',
    env: environment_1.Environments.production,
    async run(toolbox) {
        const options = toolbox.parameters.options || {};
        const { distDir } = await packager_1.preparePackage(paths_1.CWD);
        const packageManager = environment_1.getPackageManager();
        const cmdArgs = [packageManager, 'publish', distDir];
        if (options.tag) {
            cmdArgs.push('--tag', options.tag);
        }
        if (options.access) {
            cmdArgs.push('--access', options.access);
        }
        if (options.dryRun) {
            cmdArgs.push('--dry-run');
        }
        if (options.otp) {
            cmdArgs.push('--otp', options.otp);
        }
        const command = cmdArgs.join(' ');
        gluegun_1.print.info(`Running: ${command}`);
        const output = await gluegun_1.system.run(command);
        gluegun_1.print.success(` ${output}`);
    },
});
exports.default = publishCommand;
//# sourceMappingURL=publish.js.map