"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const gluegun_1 = require("gluegun");
const jest_cli_1 = __importDefault(require("jest-cli"));
const ramda_1 = require("ramda");
const environment_1 = require("../../environment");
const config_1 = require("../../jest/config");
const packager_1 = require("../../packager");
const paths_1 = require("../../paths");
const command_1 = require("../command");
function findReactDependency() {
    const pkg = packager_1.readPackage(paths_1.CWD);
    return (ramda_1.pathOr(undefined, ['dependencies', 'react'], pkg) ||
        ramda_1.pathOr(undefined, ['devDependencies', 'react'], pkg));
}
function getDefaultConfig() {
    gluegun_1.print.info('Using Default Jest Preset.');
    return config_1.jestConfigFactory({
        transformAssets: false,
    });
}
function getReactConfig() {
    gluegun_1.print.info('Using React Jest Preset.');
    return config_1.jestConfigFactory({
        environment: config_1.JestEnvironments.browser,
        react: {
            svg: true,
        },
        transformAssets: true,
    });
}
function getJestConfig() {
    return findReactDependency() ? getReactConfig() : getDefaultConfig();
}
const jestOverride = (config) => config;
const getJestOverride = ramda_1.pathOr(jestOverride, ['jestOverride']);
const STATIC_PARAMS = 3;
const testCommand = command_1.createCommand({
    dashed: false,
    description: 'Runs tests using Jest',
    env: environment_1.Environments.test,
    async run(toolbox) {
        const options = toolbox.parameters.options || {};
        const argvs = toolbox.parameters.raw.slice(STATIC_PARAMS);
        if (!environment_1.isCI && !options.coverage && !options.watchAll) {
            argvs.push('--watch');
        }
        if (environment_1.isCI) {
            argvs.push('--ci');
        }
        if (!options.config) {
            const jestConfigOverride = getJestOverride(toolbox.strawHat.config);
            const jestConfig = getJestConfig();
            const config = jestConfigOverride(jestConfig);
            argvs.push('--config', JSON.stringify(config));
        }
        jest_cli_1.default.run(argvs);
    },
});
exports.default = testCommand;
//# sourceMappingURL=test.js.map