"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ramda_1 = require("ramda");
const paths_1 = require("../paths");
var JestEnvironments;
(function (JestEnvironments) {
    JestEnvironments["node"] = "node";
    JestEnvironments["browser"] = "browser";
})(JestEnvironments = exports.JestEnvironments || (exports.JestEnvironments = {}));
function getTestEnvironment(environment) {
    switch (environment) {
        case JestEnvironments.node:
            return 'node';
        case JestEnvironments.browser:
            return 'jsdom';
        default:
            throw new Error(`${environment} is not a valid environment.`);
    }
}
const supportReactSVG = ramda_1.pathOr(false, ['react', 'svg']);
const withTestFramework = paths_1.withFile(paths_1.SETUP_TEST_FRAMEWORK);
const withTestFiles = paths_1.withFile(paths_1.SETUP_TEST_FILES);
exports.jestConfigFactory = (opts) => {
    const options = {
        environment: JestEnvironments.node,
        react: {},
        setupFiles: [],
        transformAssets: false,
        ...opts,
    };
    const moduleNameMapper = {
        '^@/(.*)$': '<rootDir>/src/$1',
    };
    const transformIgnorePatterns = ['/node_modules/'];
    const transform = {
        '\\.(js|jsx|ts|tsx|json)$': require.resolve('./transforms/babel'),
    };
    const setupFilesAfterEnv = [];
    const setupFiles = [...options.setupFiles];
    if (options.environment === JestEnvironments.browser) {
        setupFiles.push(require.resolve('react-app-polyfill/ie11'), require.resolve('./browserPolyfill'));
    }
    if (supportReactSVG(options)) {
        transform['\\.svg$'] = require.resolve('./transforms/reactSvg');
    }
    if (options.transformAssets) {
        moduleNameMapper['\\.module\\.(css|scss|sass)$'] = require.resolve('identity-obj-proxy');
        transformIgnorePatterns.push('\\.module\\.(css|sass|scss)$');
        transform['^(?!\\.(js|jsx|ts|tsx|json)$)'] = require.resolve('./transforms/file');
    }
    withTestFramework(() => setupFilesAfterEnv.push(paths_1.SETUP_TEST_FRAMEWORK));
    withTestFiles(() => setupFiles.push(paths_1.SETUP_TEST_FILES));
    return {
        collectCoverageFrom: ['<rootDir>/src/**/*.(js|jsx|ts|tsx)'],
        coverageDirectory: '<rootDir>/coverage',
        coveragePathIgnorePatterns: [
            '/node_modules/',
            '/__mocks__/',
            '/__tests__/',
            '.story.(js|jsx|ts|tsx)$',
            '.d.ts$',
        ],
        moduleFileExtensions: ['js', 'json', 'jsx', 'ts', 'tsx'],
        moduleNameMapper,
        resolver: require.resolve('jest-pnp-resolver'),
        roots: ['<rootDir>/src'],
        setupFiles,
        // TODO Fix this when Jest release the feature
        // Related to https://github.com/facebook/jest/pull/7119
        setupTestFrameworkScriptFile: setupFilesAfterEnv[0],
        testEnvironment: getTestEnvironment(options.environment),
        testMatch: ['<rootDir>/src/**/*.test.(js|jsx|ts|tsx)'],
        transform,
        transformIgnorePatterns,
    };
};
//# sourceMappingURL=config.js.map