"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs-extra"));
const path = __importStar(require("path"));
const ramda_1 = require("ramda");
const utils_1 = require("./utils");
const moduleFileExtensions = ['ts', 'tsx', 'js', 'jsx'];
const pathExists = ramda_1.memoizeWith(ramda_1.identity, (file) => fs.pathExistsSync(file));
/**
 * Current Working Directory (`process.cwd()`)
 *
 * Make sure any symlinks in the project folder are resolved:
 * https://github.com/facebook/create-react-app/issues/637
 */
exports.CWD = fs.realpathSync(process.cwd());
exports.DOT_ENV_FILE_PATH = resolve('.env')(exports.CWD);
exports.YARN_LOCK_PATH = resolve('yarn.lock')(exports.CWD);
exports.SRC_PATH = resolve('src')(exports.CWD);
exports.NODE_MODULES = resolve('node_modules')(exports.CWD);
exports.README_PATH = resolve('README.md')(exports.CWD);
exports.DOCS_PATH = resolve('docsDist')(exports.CWD);
exports.JSON_DOCS_PATH = resolve('docs.json')(exports.DOCS_PATH);
exports.PACKAGE_JSON_PATH = resolve('package.json')(exports.CWD);
exports.PUBLIC_PATH = resolve('public')(exports.CWD);
exports.DIST_PATH = resolve('dist')(exports.CWD);
exports.STATS_PATH = resolve('bundle-stats.json')(exports.DIST_PATH);
exports.HTML_PATH = resolve('index.html')(exports.PUBLIC_PATH);
exports.STRAW_HAT_CONFIG_PATH = resolve('straw-hat.config.js')(exports.CWD);
exports.SETUP_TEST_FRAMEWORK = resolveModule('__tests__/setupFramework')(exports.SRC_PATH);
exports.SETUP_TEST_FILES = resolveModule('__tests__/setupFiles')(exports.SRC_PATH);
/**
 * Run callbacks depending if the `file` exists or not. Useful for lazy
 * evaluation.
 *
 * @param file The path to the file you want to check.
 */
exports.withFile = file => {
    const exists = pathExists(file);
    return (withFileCallback, withoutFileCallback = utils_1.noop) => exists ? withFileCallback() : withoutFileCallback();
};
function resolve(relativePath) {
    return appPath => path.resolve(appPath, relativePath);
}
exports.resolve = resolve;
/**
 * Resolve the current path using multiple files extensions. It will try to find
 * the first path that matches using the extension from
 * {@link moduleFileExtensions} list or it resolve with `.js` extension
 * otherwise.
 */
function resolveModule(relativePath) {
    return (appPath) => {
        for (const ext of moduleFileExtensions) {
            const filePath = resolve(`${relativePath}.${ext}`)(appPath);
            const exists = pathExists(filePath);
            if (exists) {
                return filePath;
            }
        }
        return resolve(`${relativePath}.js`)(appPath);
    };
}
//# sourceMappingURL=paths.js.map