"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const errorOverlayMiddleware_1 = __importDefault(require("react-dev-utils/errorOverlayMiddleware"));
const evalSourceMapMiddleware_1 = __importDefault(require("react-dev-utils/evalSourceMapMiddleware"));
const ignoredFiles_1 = __importDefault(require("react-dev-utils/ignoredFiles"));
const noopServiceWorkerMiddleware_1 = __importDefault(require("react-dev-utils/noopServiceWorkerMiddleware"));
const paths_1 = require("../paths");
function devServerConfigFactory(params) {
    return {
        clientLogLevel: 'none',
        compress: true,
        contentBase: paths_1.PUBLIC_PATH,
        // WebpackDevServer 2.4.3 introduced a security fix that prevents remote
        // websites from potentially accessing local content through DNS rebinding:
        // https://github.com/webpack/webpack-dev-server/issues/887
        // https://medium.com/webpack/webpack-dev-server-middleware-security-issues-1489d950874a
        // However, it made several existing use cases such as development in cloud
        // environment or subdomains in development significantly more complicated:
        // https://github.com/facebook/create-react-app/issues/2271
        // https://github.com/facebook/create-react-app/issues/2233
        // While we're investigating better solutions, for now we will take a
        // compromise. Since our WDS configuration only serves files in the `public`
        // folder we won't consider accessing them a vulnerability. However, if you
        // use the `proxy` feature, it gets more dangerous because it can expose
        // remote code execution vulnerabilities in backend like Django and Rails.
        // So we will disable the host check normally, but enable it if you have
        // specified the `proxy` setting. Finally, we let you override it if you
        // really know what you're doing with a special environment variable.
        disableHostCheck: !params.proxy || params.dangerouslyDisableHostCheck,
        historyApiFallback: {
            // See https://github.com/facebook/create-react-app/issues/387.
            disableDotRule: true,
        },
        host: params.host,
        hot: true,
        https: params.protocol === 'https',
        overlay: false,
        proxy: params.proxy,
        public: params.allowedHost,
        publicPath: params.publicPath,
        quiet: true,
        watchContentBase: true,
        // Reportedly, this avoids CPU overload on some systems.
        // https://github.com/facebook/create-react-app/issues/293
        // src/node_modules is not ignored to support absolute imports
        // https://github.com/facebook/create-react-app/issues/1065
        watchOptions: {
            ignored: ignoredFiles_1.default(paths_1.SRC_PATH),
        },
        // @ts-ignore TODO fix webpack-dev-server to include `server` in 2nd param.
        // https://github.com/webpack/webpack-dev-server/blob/b3217ca8dc6b371a160b6749b949ab09d7b9f6d7/lib/Server.js#L450
        before(app, server) {
            if (params.devServerOverride) {
                params.devServerOverride(app);
            }
            app.use(evalSourceMapMiddleware_1.default(server));
            app.use(errorOverlayMiddleware_1.default());
            // https://github.com/facebook/create-react-app/issues/2272#issuecomment-302832432
            app.use(noopServiceWorkerMiddleware_1.default());
        },
    };
}
exports.devServerConfigFactory = devServerConfigFactory;
//# sourceMappingURL=devServerConfig.js.map