"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const neutrino_1 = __importDefault(require("neutrino"));
const ramda_1 = require("ramda");
const environment_1 = require("../../environment");
const paths_1 = require("../../paths");
const utils_1 = require("../../utils");
const presets_1 = require("./presets");
const noopMiddleware = () => (neutrino) => neutrino;
const getEntry = ramda_1.pathOr({ index: 'index' }, ['app', 'entry']);
const getNeutrinoMiddleware = ramda_1.pathOr(noopMiddleware, [
    'neutrinoMiddleware',
]);
function configFactory(opts) {
    const publicUrl = utils_1.withoutSlash(opts.publicPath);
    const sourceMapPublicPath = opts.sourceMapPublicPath
        ? utils_1.withoutSlash(opts.sourceMapPublicPath)
        : publicUrl;
    const options = {
        cwd: paths_1.CWD,
        envVariables: environment_1.readEnv({
            NODE_ENV: opts.env,
            PUBLIC_URL: publicUrl,
        }),
        generateSourceMap: true,
        htmlPath: paths_1.HTML_PATH,
        inlineRuntimeChunk: true,
        nodeModules: paths_1.NODE_MODULES,
        packagePath: paths_1.PACKAGE_JSON_PATH,
        publicUrl,
        srcPath: paths_1.SRC_PATH,
        ...opts,
        sourceMapPublicPath,
    };
    const entry = getEntry(opts.strawHatConfig);
    const customMiddleware = getNeutrinoMiddleware(opts.strawHatConfig);
    return neutrino_1.default({
        options: {
            mains: entry,
            output: paths_1.DIST_PATH,
        },
        use: [presets_1.general(options), customMiddleware(options)],
    });
}
exports.configFactory = configFactory;
//# sourceMappingURL=index.js.map