"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ramda_1 = require("ramda");
const webpack_1 = __importDefault(require("webpack"));
const utils_1 = require("../../utils");
const hotReplacementPlugin = utils_1.createMiddleware(neutrino => {
    neutrino.config
        .plugin('hotReplacement')
        .use(webpack_1.default.HotModuleReplacementPlugin);
    return neutrino;
});
const addHotEntry = (neutrino) => (entryName) => {
    // Include an alternative client for WebpackDevServer. A client's job is to
    // connect to WebpackDevServer by a socket and get notified about changes.
    // When you save a file, the client will either apply hot updates (in case
    // of CSS changes), or refresh the page (in case of JS changes). When you
    // make a syntax error, this client will display a syntax error overlay.
    // Note: instead of the default WebpackDevServer client, we use a custom one
    // to bring better experience for Create React App users. You can replace
    // the line below with these two lines if you prefer the stock client:
    // require.resolve('webpack-dev-server/client') + '?/',
    // require.resolve('webpack/hot/dev-server'),
    neutrino.config
        .entry(entryName)
        .prepend(require.resolve('react-dev-utils/webpackHotDevClient'));
    return neutrino;
};
const getMains = (neutrino) => neutrino.options.mains;
const addHotEntries = (neutrino) => ramda_1.compose(ramda_1.always(neutrino), ramda_1.map(addHotEntry(neutrino)), ramda_1.keys, getMains)(neutrino);
exports.hotReplacement = utils_1.createMiddlewareFactory(options => ramda_1.when(utils_1.development(options), ramda_1.compose(addHotEntries, hotReplacementPlugin)));
//# sourceMappingURL=hotReplacement.js.map