"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ramda_1 = require("ramda");
const terser_webpack_plugin_1 = __importDefault(require("terser-webpack-plugin"));
const utils_1 = require("../../utils");
const tenserPlugin = utils_1.createMiddlewareFactory(options => neutrino => {
    neutrino.config.optimization.minimizer('javascript').use(terser_webpack_plugin_1.default, [
        {
            // Enable file caching
            cache: true,
            // Use multi-process parallel running to improve the build speed
            // Default number of concurrent runs: os.cpus().length - 1
            parallel: true,
            sourceMap: options.generateSourceMap,
            terserOptions: {
                compress: {
                    // Disabled because of an issue with Uglify breaking seemingly
                    // valid code:
                    // https://github.com/facebook/create-react-app/issues/2376
                    // Pending further investigation:
                    // https://github.com/mishoo/UglifyJS2/issues/2011
                    comparisons: false,
                    ecma: 5,
                    // Disabled because of an issue with Terser breaking valid code:
                    // https://github.com/facebook/create-react-app/issues/5250
                    // Pending further investigation:
                    // https://github.com/terser-js/terser/issues/120
                    inline: 2,
                    warnings: false,
                },
                mangle: {
                    safari10: true,
                },
                output: {
                    // Turned on because emoji and regex is not minified properly
                    // using default
                    // https://github.com/facebook/create-react-app/issues/2488
                    ascii_only: true,
                    comments: false,
                    ecma: 5,
                },
                parse: {
                    // we want terser to parse ecma 8 code. However, we don't want it
                    // to apply any minification steps that turns valid ecma 5 code
                    // into invalid ecma 5 code. This is why the 'compress' and 'output'
                    // sections only apply transformations that are ecma 5 safe
                    // https://github.com/facebook/create-react-app/pull/4234
                    ecma: 8,
                },
            },
        },
    ]);
    return neutrino;
});
exports.tenser = utils_1.createMiddlewareFactory(options => ramda_1.when(utils_1.production(options), tenserPlugin(options)));
//# sourceMappingURL=tenser.js.map