"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = __importStar(require("path"));
const ramda_1 = require("ramda");
const environment_1 = require("../../../environment");
const utils_1 = require("../utils");
const envVariables_1 = require("./envVariables");
const ignoreMoment_1 = require("./ignoreMoment");
const manifest_1 = require("./manifest");
const devtoolModuleFilenameTemplate = (info) => path.resolve(info.absoluteResourcePath).replace(/\\/g, '/');
const entry = utils_1.createMiddleware(neutrino => {
    // We include the app code last so that if there is a runtime error during
    // initialization, it doesn't blow up the WebpackDevServer client, and
    // changing JS code would still trigger a refresh.
    Object.entries(neutrino.options.mains).forEach(main => {
        const name = main[0];
        const config = main[1];
        neutrino.config.entry(`${name}.bundle`).add(config.entry);
    });
    return neutrino;
});
const output = utils_1.createMiddlewareFactory(options => neutrino => {
    neutrino.config.output.merge({
        chunkFilename: `static/js/[name].chunk.js`,
        devtoolModuleFilenameTemplate,
        filename: `[name].js`,
        pathinfo: environment_1.isDevelopment(options.env),
        publicPath: options.publicPath,
    });
    neutrino.config.when(environment_1.isProduction(options.env), (config) => {
        config.output.merge({
            chunkFilename: `static/js/[name].chunk.js`,
            filename: `static/js/[name].js`,
            path: neutrino.options.output,
        });
    });
    return neutrino;
});
const addNodePathToModules = utils_1.createMiddleware(neutrino => {
    neutrino.config.resolve.modules.add('node_modules').merge(
    // https://github.com/facebook/create-react-app/issues/253
    process.env.NODE_PATH.split(path.delimiter).filter(Boolean));
    return neutrino;
});
exports.project = utils_1.createMiddlewareFactory(opts => {
    const options = {
        envVariables: {},
        ...opts,
    };
    const production = environment_1.isProduction(options.env);
    return neutrino => {
        neutrino.config.merge({
            bail: production,
            context: neutrino.options.root,
            devtool: production ? false : 'cheap-module-source-map',
            mode: options.env,
            module: {
                strictExportPresence: true,
            },
            node: {
                child_process: 'empty',
                dgram: 'empty',
                fs: 'empty',
                module: 'empty',
                net: 'empty',
                tls: 'empty',
            },
            // Turn off performance processing because we utilize our own hints via
            // the FileSizeReporter
            performance: {
                hints: false,
            },
            resolve: {
                alias: {
                    // These are the reasonable defaults supported by the Node ecosystem.
                    // We also include JSX as a common component filename extension to support
                    // some tools, although we do not recommend using it, see:
                    // https://github.com/facebook/create-react-app/issues/290
                    // `web` extension prefixes have been added for better support
                    // for React Native Web.
                    // Support React Native Web
                    // https://www.smashingmagazine.com/2016/08/a-glimpse-into-the-future-with-react-native-for-web/
                    'react-native': 'react-native-web',
                },
                extensions: ['.js', '.jsx', '.json', '.ts', '.tsx'],
            },
        });
        return ramda_1.compose(ignoreMoment_1.ignoreMoment, manifest_1.manifest(options), envVariables_1.envVariables(options), addNodePathToModules, output(options), entry)(neutrino);
    };
});
//# sourceMappingURL=project.js.map